/* Kendal Funk and Andrew Q. Philips, "Representative Budgeting: Women Mayors
* and the Composition of Spending in Local Governments" 
* Political Research Quarterly
*
* This file replicates all other tables
*
* Last Updated: 4/13/18
* ---------------------------------------------------------------------------*/

cd "~/Dropbox/Kendall-Andy/Text/PRQ/PRQ Replication"


* --------------------------------------------------------------------------
* Table 1: difference of means tests
* --------------------------------------------------------------------------
use "Funk-Philips-PRQ-diffofmeans.dta", clear
global fem pcteducation_edu pcthealth_hlt pctsocialassistance_asst pctculture_cul pcthabitation_hab pctenvironment_env pctcitizenrights_cit
global masc pcturbanism_urb pcttransportation_trp pctagriculture_ag pctsocialsecurity_ss pctsanitation_san pctsportsleisure_spt pctenergy_eng pctcommerceservices_bus pctpublicsafety_safe pctemployment_emp pctindustry_ind pctdefense_def pctsciencetechnology_sci pctagrarianeconomy_agecon pctinternationalrelations_ir
global neut pctadministration_adm pctlegislative_leg pctspecialobligations_obl pctjudiciary_jud pctcommunications_com pctjustice_just

* Sum stats and difference of means for feminine issues
foreach var in $fem {
sum `var' 
ttest `var', by(mayorfemale) 
} 

* Sum stats and difference of means for masculine issues
foreach var in $masc {
sum `var' 
ttest `var', by(mayorfemale) 
} 

* Sum stats and difference of means for neutral issues
foreach var in $neut {
sum `var' 
ttest `var', by(mayorfemale) 
} 

* Sum stats and difference of means for aggregate issues
foreach var in femnew mascnew neutnew {
sum `var' 
ttest `var', by(mayorfemale) 
} 


* --------------------------------------------------------------------------
* Table S4: difference of means tests on public opinion from LAPOP (in SI)
* --------------------------------------------------------------------------
* these come from various sources:
use "Funk-Philips-PRQ-LAPOP2007.dta", clear
ttest gen7, by(Q1) // University ed more important for men than for women

use "Funk-Philips-PRQ-LAPOP2008.dta", clear
ttest braimp2, by(q1) // Gov should offer less services like health and edu to lower taxes

use "Funk-Philips-PRQ-LAPOP2010.dta", clear
ttest vb7a, by(q1) // prefer more spending (and more taxes) for higher education 
ttest vb7b, by(q1) // prefer more spending and taxes for high school

use "Funk-Philips-PRQ-LAPOP20042014.dta", clear
ttest bragen1, by(q1) // When there aren't enough jobs, men should have priority in hiring
ttest cct1b, by(q1) // Receive Bolsa Familia benefits 
ttest cct4bra, by(q1) // In favor of expanding Bolsa Familia
ttest cp7, by(q1) // Attend parent association meetings more frequently 
ttest mov1, by(q1) // Belong to a lower social class
ttest n1, by(q1) // Disatisfied with administration's efforts to combat poverty 
ttest q10, by(q1) // Monthly family income 
ttest q10g, by(q1) // Personal income 
ttest q12, by(q1) // Num children


* --------------------------------------------------------------------------
* Table S6: Most Important Problem/spending preferences from LAPOP (in SI)
* --------------------------------------------------------------------------
* Most important problem 
tab a4 if q1==1 // men
tab a4 if q1==2 // women 

* Gov spending priorities 
tab soc2a if q1==1 // men
tab soc2a if q1==2  // women


* --------------------------------------------------------------------------
* Table S5: Public opinion data from WVS (in SI)
* --------------------------------------------------------------------------
* these come from 2 waves:
use "Funk-Philips-PRQ-WVS2006.dta", clear
ttest V11, by(V235) // subjective state of health
ttest V56, by(V235) // num children
ttest V62, by(V235) // university more important for boy than girl
ttest V68, by(V235) // satisfaction w/ household finances
ttest V253, by(V235)  // income group

use "Funk-Philips-PRQ-WVS2014.dta", clear
ttest V11, by(V240) // subjective state of health
ttest V52, by(V240) // university more important for boy than girl
ttest V58, by(V240) // num children
ttest V182, by(V240) // worried about not being able to give child good education
ttest V190, by(V240) // lacked medicine in last 12 months
ttest V238, by(V240) // subjective social class
ttest V239, by(V240) // income group





